@@ -44,11 +44,14 @@ static int pax_seccomp_rules_add(scmp_filter_ctx ctx, int syscalls[], size_t num
 static void
 pax_seccomp_sigal(__unused__ int signo, siginfo_t *info, __unused__ void *context)
 {
+#ifdef si_syscall
 	warn("seccomp violated: syscall %i", info->si_syscall);
 	fflush(stderr);
-#ifdef si_syscall
 	warn("  syscall = %s",
 		seccomp_syscall_resolve_num_arch(seccomp_arch_native(), info->si_syscall));
+	fflush(stderr);
+#else
+	warn("seccomp violated: syscall unknown (no si_syscall)");
 #endif
 	kill(getpid(), SIGSYS);
 	_exit(1);
@@ -109,6 +112,9 @@ static void pax_seccomp_init(bool allow_forking)
 		SCMP_SYS(brk),
 		SCMP_SYS(capget),
 		SCMP_SYS(chdir),
+		SCMP_SYS(dup),
+		SCMP_SYS(dup2),
+		SCMP_SYS(dup3),
 		SCMP_SYS(exit),
 		SCMP_SYS(exit_group),
 		SCMP_SYS(faccessat),
@@ -120,6 +126,9 @@ static void pax_seccomp_init(bool allow_forking)
 		SCMP_SYS(_llseek),
 		SCMP_SYS(mprotect),
 
+		/* Syscalls listed because of compiler settings.  */
+		SCMP_SYS(futex),
+
 		/* Syscalls listed because of sandbox.  */
 		SCMP_SYS(readlink),
 
